import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:taskservice/Common/JXColors.dart';
import 'package:taskservice/Model/JXMemberModel.dart';
import 'package:taskservice/src/acclist/page_acclist.dart';
import 'package:taskservice/src/crtacc/page_crtacc.dart';
import 'package:taskservice/src/custom_widgets.dart';

class MyHomePage extends StatefulWidget {
  MyHomePage({Key key, this.title}) : super(key: key);

  final String title;

  @override
  _MyHomePageState createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  // 参数
  /*空白区域键盘消失控制*/
  FocusNode blankNode = FocusNode();

  /*搜索值*/
  static final TextEditingController _searchController =
      TextEditingController();

  /*tableView*/
  List<Widget> _cells = [];
  List<JXMemberModel> _basesource = [];

  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    _basesource = [
      JXMemberModel()
        ..name = 'Jack'
        ..tel = '156000'
        ..addr = '广州',
      JXMemberModel()
        ..name = 'Ros'
        ..tel = '1523'
        ..addr = '广州12',
      JXMemberModel()
        ..name = 'Rose'
        ..tel = '156186'
        ..addr = '广州12',
      JXMemberModel()
        ..name = 'Base'
        ..tel = '186'
        ..addr = '广州12',
    ];

    for (JXMemberModel model in _basesource) {
      _cells.add(theCellBuilder(context, model));
    }
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () {
        FocusScope.of(context).requestFocus(blankNode);
      },
      child: MyScaffold(
        title: '吉祥之舍',
        body: Column(
          mainAxisAlignment: MainAxisAlignment.start,
          children: <Widget>[
            SearchBar(
              hint: '快速筛选',
              onTextChanged: (value) {
                filterMember();
              },
              focusNode: blankNode,
              onBtnClear: () {
                /*清空*/
                setState(() {
                  _searchController.clear();
                  filterMember();
                });
              },
              searchController: _searchController,
            ),
            Expanded(
                child: Container(
              color: JXColors.kF0F0F0,
              child: ListView.builder(
                padding: EdgeInsets.only(left: 12.0, right: 12.0),
                itemCount: _cells.length,
                itemExtent: 92.0,
                itemBuilder: (BuildContext context, int row) {
                  return _cells[row];
                },
              ),
            )),
            Row(
              mainAxisAlignment: MainAxisAlignment.start,
              children: <Widget>[
                Expanded(
                  child: CupertinoButton(
                    onPressed: () {
                      Navigator.of(context).pushNamed('$CreateAccPage');
                    },
                    padding: EdgeInsets.all(0),
                    color: JXColors.kFFFFFF,
                    borderRadius: BorderRadius.all(Radius.circular(0)),
                    child: Text(
                      '新建会员',
                      style: TextStyle(
                        fontSize: 14,
                        color: JXColors.k101E40,
                      ),
                    ),
                  ),
                ),
                Expanded(
                  child: CupertinoButton(
                    onPressed: () {
                      print('会员列表');
                      Navigator.of(context).pushNamed('$AccountListPage');
                    },
                    padding: EdgeInsets.all(0),
                    color: JXColors.k101E40,
                    borderRadius: BorderRadius.all(Radius.circular(0)),
                    child: Text('会员列表',
                        style: TextStyle(
                          fontSize: 14,
                          color: JXColors.kFFFFFF,
                        )),
                  ),
                ),
              ],
            )
          ],
        ),
      ),
    );
  }

  /*筛选列表数据*/
  void filterMember() {
    String text = _searchController.text;
    print('筛选：$text');

    List tmpItems = [];
    _cells.clear();
    if (text.isEmpty) {
      tmpItems.addAll(_basesource);
    } else {
      for (JXMemberModel member in _basesource) {
        bool has = false;
        /*filter name*/
        if (member.name.toLowerCase().contains(text.toLowerCase())) {
          tmpItems.add(member);
          has = true;
        }
        /*filter tel*/
        if (!has && (member.tel.contains(text))) {
          tmpItems.add(member);
        }
      }
    }
    for (JXMemberModel model in tmpItems) {
      _cells.add(theCellBuilder(context, model));
    }
    setState(() {});
  }

  /*cell*/
  Widget theCellBuilder(BuildContext context, JXMemberModel model) {
    return GestureDetector(
        onTap: () {
          print('click cell, name:${model.name}');
        },
        child: Container(
          height: 92.0,
          alignment: Alignment.topCenter,
          child: Container(
            height: 80.0,
            alignment: Alignment.center,
            decoration: BoxDecoration(
              color: JXColors.kFFFFFF,
              borderRadius: BorderRadius.all(Radius.circular(8.0)),
              border: Border.all(
                color: JXColors.kE6E6E6,
              ),
            ),
            child: Column(
              mainAxisAlignment: MainAxisAlignment.start,
              children: <Widget>[
                Row(
                  mainAxisAlignment: MainAxisAlignment.start,
                  children: <Widget>[
                    Container(
                      padding: EdgeInsets.only(left: 12.0, top: 12.0),
                      width: 120.0,
                      child: Text(
                        model.name,
                        style: TextStyle(
                          fontSize: 16,
                          color: JXColors.k2E3032,
                        ),
                      ),
                    ),
                    Expanded(
                      child: Container(
                        padding: EdgeInsets.only(top: 12.0, right: 12.0),
                        child: Text(
                          model.tel,
                          textAlign: TextAlign.right,
                          style: TextStyle(
                            fontSize: 16,
                            color: JXColors.k2E3032,
                          ),
                        ),
                      ),
                    )
                  ],
                ),
                Row(
                  mainAxisAlignment: MainAxisAlignment.start,
                  children: [
                    Expanded(
                      child: Container(
                        padding: EdgeInsets.only(left: 18, top: 12, right: 18),
                        child: Text(
                          '任务:${model.addr}',
                          overflow: TextOverflow.ellipsis,
                          style: TextStyle(
                            fontSize: 16,
                            color: JXColors.k2E3032,
                          ),
                        ),
                      ),
                    )
                  ],
                )
              ],
            ),
          ),
        ));
  }
}
